# FunBible

A simple terminal-based Bible reader written in Python.

Currently only supports the Bulgarian Version of the Bible, but the schema should be applicable to other versions as well.

- Supports searching for a verse (or a span of verses) by book, chapter and verse number.
- Supports finding verses by a keyword.
